@@ -29,14 +29,14 @@ sub reverse {
 
 sub remove_duplicates {
     my $self = CORE::shift;
-		my @unique;
-		my $last_node=0;
-		foreach my $node (@$self) { 
-				push @unique, $node unless( $node == $last_node);
-				$last_node= $node;
-		}
-		@$self= @unique; 
-		return $self;
+    my @unique;
+    my $last_node=0;
+    foreach my $node (@$self) { 
+        push @unique, $node unless( $node == $last_node);
+        $last_node= $node;
+    }
+    @$self= @unique; 
+    return $self;
 }
 
 
@@ -95,6 +95,17 @@ sub get_nodelist {
 	@$self;
 }
 
+sub getChildNodes {
+    my $self = CORE::shift;
+    return map { $_->getChildNodes } @$self;
+}
+
+sub getElementById {
+    my $self = CORE::shift;
+    return map { $_->getElementById } @$self;
+}
+
+       
 sub to_boolean {
 	my $self = CORE::shift;
 	return (@$self > 0) ? XML::XPathEngine::Boolean->True : XML::XPathEngine::Boolean->False;
@@ -120,11 +131,15 @@ sub to_number {
 			);
 }
 
-sub to_final_value{
+sub to_final_value {
 	my $self = CORE::shift;
 	return join('', map { $_->string_value } @$self);
 }
 
+sub string_values {
+	my $self = CORE::shift;
+	return map { $_->string_value } @$self;
+}
 1;
 __END__
 
@@ -166,6 +181,11 @@ the nodes.
 Returns the string-value of the first node in the list.
 See the XPath specification for what "string-value" means.
 
+=head2 string_values()
+
+Returns a list of the string-values of all the nodes in the list.
+
+
 =head2 to_literal()
 
 Returns the concatenation of all the string-values of all
